/******************************************************************************
* Function name         :  system.c
* returns               :  
* Created by            :  JBE, BHF
* Date Created          :  
* Company				   :  Avnet
* Description           :  This program tests the flash by doing the following:
*                       :  1) Erase the device; 2) Write Sample Data; 3) Readback
*                       :  and compare sample data
* Notes                 :  
******************************************************************************/
#include "xparameters.h"
#include "xuartlite_l.h"
#include "xgpio_l.h"
#include "stdio.h"
#include "xbasic_types.h"

#define FLASHBASEADDR    XPAR_FLASH_2MX16_MEM0_BASEADDR
#define FLASHBYTES       (XPAR_FLASH_2MX16_MEM0_HIGHADDR - XPAR_FLASH_2MX16_MEM0_BASEADDR + 1)
#define FLASHHWORDS      (FLASHBYTES / 2)
#define FLASHWORDS       (FLASHBYTES / 4)

#define LEDBASEADDR      XPAR_LEDS_4BIT_BASEADDR

#define TEST_WORDS       FLASHWORDS
#define TEST_HWORDS      TEST_WORDS * 2
#define TEST_BYTES       TEST_WORDS * 4
#define BLOCKS_TO_ERASE  64

#define WAIT_LENGTH			1000000

void _wait(loop_count)
int	loop_count;
{
    volatile int	sum, data;
    sum	= 0;

    for (data = 0; data < loop_count; data++) {
        sum = (data << 8);
    }
  return;
}

int main(void)
{
	Xuint32 i, j;
	Xuint16 DataWord16;
    Xuint32 DataWord32, TestWord32;
	Xuint8  error = 0;

xil_printf("         ####################################################\n\r");
xil_printf("         #                                                  #\n\r");
xil_printf("         #                     Avnet XTM                    #\n\r");
xil_printf("         #            Spartan-3A 400 Evaluation Board       #\n\r");
xil_printf("         #          Spansion S29GL Test with MicroBlaze     #\n\r");
xil_printf("         ####################################################\n\r");
xil_printf("\n\r");
xil_printf("\n\r");

	xil_printf("FLASHBYTES  =: 0x%x \n\r", FLASHBYTES);
	xil_printf("FLASHHWORDS =: 0x%x \n\r", FLASHHWORDS);
	xil_printf("FLASHWORDS  =: 0x%x \n\r", FLASHWORDS);

	//--------------------------------------------------------------
	XGpio_mSetDataDirection(LEDBASEADDR, 1,0x00); 

// Get Product ID

	xil_printf("Flash ID Test\n\r");
	// 3-cycle Autoselect Entry Command
	XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x00AA);
	XIo_Out16(FLASHBASEADDR + (0x2AA << 1),0x0055);
	XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x0090);

	// Manufacturer Code is read for A[7:0] = 0x00
	// Expecting 0x0001
	DataWord16 = XIo_In16(FLASHBASEADDR + 0x0);
	xil_printf("Manufacturer Code = : 0x%04x \n\r", DataWord16);
	if (DataWord16 != 0x0001) error = 1;
	
	// Device Code #1 is read for A[7:0] = 0x01
	// Expecting 0x227E
	DataWord16 = XIo_In16(FLASHBASEADDR + (0x1 << 1));
	xil_printf("Device ID #1      =: 0x%04x \n\r", DataWord16);
	if (DataWord16 != 0x227E) error = 1;
	// Device Code #2 is read for A[7:0] = 0x0E
	// Expecting 0x221D
	DataWord16 = XIo_In16(FLASHBASEADDR + (0xE << 1));
	xil_printf("Device ID #2      =: 0x%04x \n\r", DataWord16);
	if (DataWord16 != 0x221D) error = 1;
	// Device Code #3 is read for A[7:0] = 0x0F
	// Expecting 0x2200
	DataWord16 = XIo_In16(FLASHBASEADDR + (0xF << 1));
	xil_printf("Device ID #3      =: 0x%04x \n\r", DataWord16);
	if (DataWord16 != 0x2200) error = 1;
	
	if (error)
    {
        xil_printf("ID Test failed.\n\n\r");
  		XGpio_mSetDataReg(LEDBASEADDR, 1,0x1);
    }
	else
	{
        xil_printf("ID Test passed.\n\n\r");
		XGpio_mSetDataReg(LEDBASEADDR, 1,0x8);
    }
    
    // Send the Reset command to exit the auto-select command sequence
	XIo_Out16(FLASHBASEADDR,0x00F0);
    
	error = 0;

// Perform a Chip Erase, one block at a time
	xil_printf("Erasing %d blocks, starting...\n\r", BLOCKS_TO_ERASE);

// Perform a Chip Erase
	for(i = 0; i < BLOCKS_TO_ERASE; i ++)
	{
		// Erase Sector command
        XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x00AA);
        XIo_Out16(FLASHBASEADDR + (0x2AA << 1),0x0055);
        XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x0080);
        XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x00AA);
        XIo_Out16(FLASHBASEADDR + (0x2AA << 1),0x0055);
		XIo_Out16(FLASHBASEADDR + (i*0x8000 << 1),0x30);
		xil_printf("%d\r",i);

		do
		{
			// Read status register 
			DataWord16 = XIo_In16(FLASHBASEADDR + (i*0x8000 << 1));
			// xil_printf("%x  ", DataWord16);
		}
		while( (DataWord16 & 0x0080) == 0 );
	}

	xil_printf("\n\rSectors 0-%d erased\n\r", BLOCKS_TO_ERASE-1);
	xil_printf("\n\rChip Erase complete - verifying\n\r");

// Verify Chip Erase
	// Readback entire chip, comparing to 0xFF
	for (i = 0; i < TEST_WORDS; i++)
	{
		DataWord32 = XIo_In32(FLASHBASEADDR + (i << 2));
		if (DataWord32 != 0xFFFFFFFF)
		{
			xil_printf("Chip Erase Failed at %x\n\r", i);
			xil_printf("Data read was %x\n\r",DataWord32);
			error = 1;
			i = TEST_WORDS;
		}
	}
	if(!error)
		xil_printf("Chip Erased successfully\n\n\r");

// Write Test using Byte Program mode
xil_printf("Data being written\n\r");
	for (i = 0; i < TEST_HWORDS; i++)
	{
        XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x00AA);
        XIo_Out16(FLASHBASEADDR + (0x2AA << 1),0x0055);
        XIo_Out16(FLASHBASEADDR + (0x555 << 1),0x00A0);
		XIo_Out16(FLASHBASEADDR + (i << 1),i);

		do
		{
			// Read status register command
			DataWord16 = XIo_In16(FLASHBASEADDR + (i << 1));
			// xil_printf("%x  ", DataWord16);
		}
		while( (DataWord16 & 0x0080) != (i & 0x0080) );
	}
	xil_printf("Test Data Written; reading back\n\r", i);

// Readback all bytes
	error = 0;
	for (i = 0; i < TEST_BYTES; i=i+4)
	{
		DataWord32 = XIo_In32(FLASHBASEADDR + i);
		//xil_printf("%x Data read was %x\n\r",i,DataWord32);
		TestWord32 = ( (i<<(16-1)) | (((i>>1)& 0xFFFF) + 1));
		if (DataWord32 != TestWord32)
		{
			xil_printf("Flash Test FAILED at 0x%x\n\r", (i << 1));
			xil_printf("Data read was 0x%x\n\r",DataWord32);
			xil_printf("Exp. Data was 0x%x\n\r",TestWord32);
			error = 1;
			i = TEST_BYTES;
		}
	}
	if(!error)
	{
		xil_printf("Flash Test PASSED!\n\r");
		xil_printf("Ending Address Read was 0x%x\n\r", i);
		xil_printf("Last Data Read was %x\n\r", DataWord32);
	}

	//--------------------------------------------------------------
	
	while(1)
	{
		XGpio_mSetDataReg(LEDBASEADDR, 1,0xE);
		_wait(WAIT_LENGTH);
		XGpio_mSetDataReg(LEDBASEADDR, 1,0xD);
		_wait(WAIT_LENGTH);
		XGpio_mSetDataReg(LEDBASEADDR, 1,0xB);
		_wait(WAIT_LENGTH);
		XGpio_mSetDataReg(LEDBASEADDR, 1,0x7);
		_wait(WAIT_LENGTH);
	}

	return 0;

}
